/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.kendo.ui;

import java.util.Locale;

/**
 * Provides all Kendo UI supported culture identifiers
 * 
 * @author Sebastien Briquet - sebfz1
 */
public enum KendoCulture
{
	AF("af"), // lf
	AF_ZA("af-ZA"), // lf
	AM("am"), // lf
	AM_ET("am-ET"), // lf
	AR("ar"), // lf
	AR_AE("ar-AE"), // lf
	AR_BH("ar-BH"), // lf
	AR_DZ("ar-DZ"), // lf
	AR_EG("ar-EG"), // lf
	AR_IQ("ar-IQ"), // lf
	AR_JO("ar-JO"), // lf
	AR_KW("ar-KW"), // lf
	AR_LB("ar-LB"), // lf
	AR_LY("ar-LY"), // lf
	AR_MA("ar-MA"), // lf
	ARN("arn"), // lf
	ARN_CL("arn-CL"), // lf
	AR_OM("ar-OM"), // lf
	AR_QA("ar-QA"), // lf
	AR_SA("ar-SA"), // lf
	AR_SY("ar-SY"), // lf
	AR_TN("ar-TN"), // lf
	AR_YE("ar-YE"), // lf
	AS("as"), // lf
	AS_IN("as-IN"), // lf
	AZ("az"), // lf
	AZ_CYRL("az-Cyrl"), // lf
	AZ_CYRL_AZ("az-Cyrl-AZ"), // lf
	AZ_LATN("az-Latn"), // lf
	AZ_LATN_AZ("az-Latn-AZ"), // lf
	BA("ba"), // lf
	BA_RU("ba-RU"), // lf
	BE("be"), // lf
	BE_BY("be-BY"), // lf
	BG("bg"), // lf
	BG_BG("bg-BG"), // lf
	BN("bn"), // lf
	BN_BD("bn-BD"), // lf
	BN_IN("bn-IN"), // lf
	BO("bo"), // lf
	BO_CN("bo-CN"), // lf
	BR("br"), // lf
	BR_FR("br-FR"), // lf
	BS("bs"), // lf
	BS_CYRL("bs-Cyrl"), // lf
	BS_CYRL_BA("bs-Cyrl-BA"), // lf
	BS_LATN("bs-Latn"), // lf
	BS_LATN_BA("bs-Latn-BA"), // lf
	CA("ca"), // lf
	CA_ES("ca-ES"), // lf
	CA_ES_VALENCIA("ca-ES-valencia"), // lf
	CHR("chr"), // lf
	CHR_CHER("chr-Cher"), // lf
	CHR_CHER_US("chr-Cher-US"), // lf
	CO("co"), // lf
	CO_FR("co-FR"), // lf
	CS("cs"), // lf
	CS_CZ("cs-CZ"), // lf
	CY("cy"), // lf
	CY_GB("cy-GB"), // lf
	DA("da"), // lf
	DA_DK("da-DK"), // lf
	DE("de"), // lf
	DE_AT("de-AT"), // lf
	DE_CH("de-CH"), // lf
	DE_DE("de-DE"), // lf
	DE_LI("de-LI"), // lf
	DE_LU("de-LU"), // lf
	DSB("dsb"), // lf
	DSB_DE("dsb-DE"), // lf
	DV("dv"), // lf
	DV_MV("dv-MV"), // lf
	EL("el"), // lf
	EL_GR("el-GR"), // lf
	EN("en"), // lf
	EN_029("en-029"), // lf
	EN_AU("en-AU"), // lf
	EN_BZ("en-BZ"), // lf
	EN_CA("en-CA"), // lf
	EN_GB("en-GB"), // lf
	EN_HK("en-HK"), // lf
	EN_IE("en-IE"), // lf
	EN_IN("en-IN"), // lf
	EN_JM("en-JM"), // lf
	EN_MY("en-MY"), // lf
	EN_NZ("en-NZ"), // lf
	EN_PH("en-PH"), // lf
	EN_SG("en-SG"), // lf
	EN_TT("en-TT"), // lf
	EN_US("en-US"), // lf
	EN_ZA("en-ZA"), // lf
	EN_ZW("en-ZW"), // lf
	ES("es"), // lf
	ES_419("es-419"), // lf
	ES_AR("es-AR"), // lf
	ES_BO("es-BO"), // lf
	ES_CL("es-CL"), // lf
	ES_CO("es-CO"), // lf
	ES_CR("es-CR"), // lf
	ES_DO("es-DO"), // lf
	ES_EC("es-EC"), // lf
	ES_ES("es-ES"), // lf
	ES_GT("es-GT"), // lf
	ES_HN("es-HN"), // lf
	ES_MX("es-MX"), // lf
	ES_NI("es-NI"), // lf
	ES_PA("es-PA"), // lf
	ES_PE("es-PE"), // lf
	ES_PR("es-PR"), // lf
	ES_PY("es-PY"), // lf
	ES_SV("es-SV"), // lf
	ES_US("es-US"), // lf
	ES_UY("es-UY"), // lf
	ES_VE("es-VE"), // lf
	ET("et"), // lf
	ET_EE("et-EE"), // lf
	EU("eu"), // lf
	EU_ES("eu-ES"), // lf
	FA("fa"), // lf
	FA_IR("fa-IR"), // lf
	FF("ff"), // lf
	FF_LATN("ff-Latn"), // lf
	FF_LATN_SN("ff-Latn-SN"), // lf
	FI("fi"), // lf
	FI_FI("fi-FI"), // lf
	FIL("fil"), // lf
	FIL_PH("fil-PH"), // lf
	FO("fo"), // lf
	FO_FO("fo-FO"), // lf
	FR("fr"), // lf
	FR_BE("fr-BE"), // lf
	FR_CA("fr-CA"), // lf
	FR_CD("fr-CD"), // lf
	FR_CH("fr-CH"), // lf
	FR_CI("fr-CI"), // lf
	FR_CM("fr-CM"), // lf
	FR_FR("fr-FR"), // lf
	FR_HT("fr-HT"), // lf
	FR_LU("fr-LU"), // lf
	FR_MA("fr-MA"), // lf
	FR_MC("fr-MC"), // lf
	FR_ML("fr-ML"), // lf
	FR_RE("fr-RE"), // lf
	FR_SN("fr-SN"), // lf
	FY("fy"), // lf
	FY_NL("fy-NL"), // lf
	GA("ga"), // lf
	GA_IE("ga-IE"), // lf
	GD("gd"), // lf
	GD_GB("gd-GB"), // lf
	GL("gl"), // lf
	GL_ES("gl-ES"), // lf
	GN("gn"), // lf
	GN_PY("gn-PY"), // lf
	GSW("gsw"), // lf
	GSW_FR("gsw-FR"), // lf
	GU("gu"), // lf
	GU_IN("gu-IN"), // lf
	HA("ha"), // lf
	HA_LATN("ha-Latn"), // lf
	HA_LATN_NG("ha-Latn-NG"), // lf
	HAW("haw"), // lf
	HAW_US("haw-US"), // lf
	HE("he"), // lf
	HE_IL("he-IL"), // lf
	HI("hi"), // lf
	HI_IN("hi-IN"), // lf
	HR("hr"), // lf
	HR_BA("hr-BA"), // lf
	HR_HR("hr-HR"), // lf
	HSB("hsb"), // lf
	HSB_DE("hsb-DE"), // lf
	HU("hu"), // lf
	HU_HU("hu-HU"), // lf
	HY("hy"), // lf
	HY_AM("hy-AM"), // lf
	ID("id"), // lf
	ID_ID("id-ID"), // lf
	IG("ig"), // lf
	IG_NG("ig-NG"), // lf
	II("ii"), // lf
	II_CN("ii-CN"), // lf
	IS("is"), // lf
	IS_IS("is-IS"), // lf
	IT("it"), // lf
	IT_CH("it-CH"), // lf
	IT_IT("it-IT"), // lf
	IU("iu"), // lf
	IU_CANS("iu-Cans"), // lf
	IU_CANS_CA("iu-Cans-CA"), // lf
	IU_LATN("iu-Latn"), // lf
	IU_LATN_CA("iu-Latn-CA"), // lf
	JA("ja"), // lf
	JA_JP("ja-JP"), // lf
	JV("jv"), // lf
	JV_LATN("jv-Latn"), // lf
	JV_LATN_ID("jv-Latn-ID"), // lf
	KA("ka"), // lf
	KA_GE("ka-GE"), // lf
	KK("kk"), // lf
	KK_KZ("kk-KZ"), // lf
	KL("kl"), // lf
	KL_GL("kl-GL"), // lf
	KM("km"), // lf
	KM_KH("km-KH"), // lf
	KN("kn"), // lf
	KN_IN("kn-IN"), // lf
	KO("ko"), // lf
	KOK("kok"), // lf
	KOK_IN("kok-IN"), // lf
	KO_KR("ko-KR"), // lf
	KU("ku"), // lf
	KU_ARAB("ku-Arab"), // lf
	KU_ARAB_IQ("ku-Arab-IQ"), // lf
	KY("ky"), // lf
	KY_KG("ky-KG"), // lf
	LB("lb"), // lf
	LB_LU("lb-LU"), // lf
	LO("lo"), // lf
	LO_LA("lo-LA"), // lf
	LT("lt"), // lf
	LT_LT("lt-LT"), // lf
	LV("lv"), // lf
	LV_LV("lv-LV"), // lf
	MG("mg"), // lf
	MG_MG("mg-MG"), // lf
	MI("mi"), // lf
	MI_NZ("mi-NZ"), // lf
	MK("mk"), // lf
	MK_MK("mk-MK"), // lf
	ML("ml"), // lf
	ML_IN("ml-IN"), // lf
	MN("mn"), // lf
	MN_CYRL("mn-Cyrl"), // lf
	MN_MN("mn-MN"), // lf
	MN_MONG("mn-Mong"), // lf
	MN_MONG_CN("mn-Mong-CN"), // lf
	MN_MONG_MN("mn-Mong-MN"), // lf
	MOH("moh"), // lf
	MOH_CA("moh-CA"), // lf
	MR("mr"), // lf
	MR_IN("mr-IN"), // lf
	MS("ms"), // lf
	MS_BN("ms-BN"), // lf
	MS_MY("ms-MY"), // lf
	MT("mt"), // lf
	MT_MT("mt-MT"), // lf
	MY("my"), // lf
	MY_MM("my-MM"), // lf
	NB("nb"), // lf
	NB_NO("nb-NO"), // lf
	NE("ne"), // lf
	NE_IN("ne-IN"), // lf
	NE_NP("ne-NP"), // lf
	NL("nl"), // lf
	NL_BE("nl-BE"), // lf
	NL_NL("nl-NL"), // lf
	NN("nn"), // lf
	NN_NO("nn-NO"), // lf
	NO("no"), // lf
	NQO("nqo"), // lf
	NQO_GN("nqo-GN"), // lf
	NSO("nso"), // lf
	NSO_ZA("nso-ZA"), // lf
	OC("oc"), // lf
	OC_FR("oc-FR"), // lf
	OM("om"), // lf
	OM_ET("om-ET"), // lf
	OR("or"), // lf
	OR_IN("or-IN"), // lf
	PA("pa"), // lf
	PA_ARAB("pa-Arab"), // lf
	PA_ARAB_PK("pa-Arab-PK"), // lf
	PA_IN("pa-IN"), // lf
	PL("pl"), // lf
	PL_PL("pl-PL"), // lf
	PRS("prs"), // lf
	PRS_AF("prs-AF"), // lf
	PS("ps"), // lf
	PS_AF("ps-AF"), // lf
	PT("pt"), // lf
	PT_AO("pt-AO"), // lf
	PT_BR("pt-BR"), // lf
	PT_PT("pt-PT"), // lf
	QUT("qut"), // lf
	QUT_GT("qut-GT"), // lf
	QUZ("quz"), // lf
	QUZ_BO("quz-BO"), // lf
	QUZ_EC("quz-EC"), // lf
	QUZ_PE("quz-PE"), // lf
	RM("rm"), // lf
	RM_CH("rm-CH"), // lf
	RO("ro"), // lf
	RO_MD("ro-MD"), // lf
	RO_RO("ro-RO"), // lf
	RU("ru"), // lf
	RU_RU("ru-RU"), // lf
	RU_UA("ru-UA"), // lf
	RW("rw"), // lf
	RW_RW("rw-RW"), // lf
	SA("sa"), // lf
	SAH("sah"), // lf
	SAH_RU("sah-RU"), // lf
	SA_IN("sa-IN"), // lf
	SD("sd"), // lf
	SD_ARAB("sd-Arab"), // lf
	SD_ARAB_PK("sd-Arab-PK"), // lf
	SE("se"), // lf
	SE_FI("se-FI"), // lf
	SE_NO("se-NO"), // lf
	SE_SE("se-SE"), // lf
	SI("si"), // lf
	SI_LK("si-LK"), // lf
	SK("sk"), // lf
	SK_SK("sk-SK"), // lf
	SL("sl"), // lf
	SL_SI("sl-SI"), // lf
	SMA("sma"), // lf
	SMA_NO("sma-NO"), // lf
	SMA_SE("sma-SE"), // lf
	SMJ("smj"), // lf
	SMJ_NO("smj-NO"), // lf
	SMJ_SE("smj-SE"), // lf
	SMN("smn"), // lf
	SMN_FI("smn-FI"), // lf
	SMS("sms"), // lf
	SMS_FI("sms-FI"), // lf
	SN("sn"), // lf
	SN_LATN("sn-Latn"), // lf
	SN_LATN_ZW("sn-Latn-ZW"), // lf
	SO("so"), // lf
	SO_SO("so-SO"), // lf
	SQ("sq"), // lf
	SQ_AL("sq-AL"), // lf
	SR("sr"), // lf
	SR_CYRL("sr-Cyrl"), // lf
	SR_CYRL_BA("sr-Cyrl-BA"), // lf
	SR_CYRL_CS("sr-Cyrl-CS"), // lf
	SR_CYRL_ME("sr-Cyrl-ME"), // lf
	SR_CYRL_RS("sr-Cyrl-RS"), // lf
	SR_LATN("sr-Latn"), // lf
	SR_LATN_BA("sr-Latn-BA"), // lf
	SR_LATN_CS("sr-Latn-CS"), // lf
	SR_LATN_ME("sr-Latn-ME"), // lf
	SR_LATN_RS("sr-Latn-RS"), // lf
	ST("st"), // lf
	ST_ZA("st-ZA"), // lf
	SV("sv"), // lf
	SV_FI("sv-FI"), // lf
	SV_SE("sv-SE"), // lf
	SW("sw"), // lf
	SW_KE("sw-KE"), // lf
	SYR("syr"), // lf
	SYR_SY("syr-SY"), // lf
	TA("ta"), // lf
	TA_IN("ta-IN"), // lf
	TA_LK("ta-LK"), // lf
	TE("te"), // lf
	TE_IN("te-IN"), // lf
	TG("tg"), // lf
	TG_CYRL("tg-Cyrl"), // lf
	TG_CYRL_TJ("tg-Cyrl-TJ"), // lf
	TH("th"), // lf
	TH_TH("th-TH"), // lf
	TI("ti"), // lf
	TI_ER("ti-ER"), // lf
	TI_ET("ti-ET"), // lf
	TK("tk"), // lf
	TK_TM("tk-TM"), // lf
	TN("tn"), // lf
	TN_BW("tn-BW"), // lf
	TN_ZA("tn-ZA"), // lf
	TR("tr"), // lf
	TR_TR("tr-TR"), // lf
	TS("ts"), // lf
	TS_ZA("ts-ZA"), // lf
	TT("tt"), // lf
	TT_RU("tt-RU"), // lf
	TZM("tzm"), // lf
	TZM_LATN("tzm-Latn"), // lf
	TZM_LATN_DZ("tzm-Latn-DZ"), // lf
	TZM_TFNG("tzm-Tfng"), // lf
	TZM_TFNG_MA("tzm-Tfng-MA"), // lf
	UG("ug"), // lf
	UG_CN("ug-CN"), // lf
	UK("uk"), // lf
	UK_UA("uk-UA"), // lf
	UR("ur"), // lf
	UR_IN("ur-IN"), // lf
	UR_PK("ur-PK"), // lf
	UZ("uz"), // lf
	UZ_CYRL("uz-Cyrl"), // lf
	UZ_CYRL_UZ("uz-Cyrl-UZ"), // lf
	UZ_LATN("uz-Latn"), // lf
	UZ_LATN_UZ("uz-Latn-UZ"), // lf
	VI("vi"), // lf
	VI_VN("vi-VN"), // lf
	WO("wo"), // lf
	WO_SN("wo-SN"), // lf
	XH("xh"), // lf
	XH_ZA("xh-ZA"), // lf
	YO("yo"), // lf
	YO_NG("yo-NG"), // lf
	ZGH("zgh"), // lf
	ZGH_TFNG("zgh-Tfng"), // lf
	ZGH_TFNG_MA("zgh-Tfng-MA"), // lf
	ZH("zh"), // lf
	ZH_CHS("zh-CHS"), // lf
	ZH_CHT("zh-CHT"), // lf
	ZH_CN("zh-CN"), // lf
	ZH_HANS("zh-Hans"), // lf
	ZH_HANT("zh-Hant"), // lf
	ZH_HK("zh-HK"), // lf
	ZH_MO("zh-MO"), // lf
	ZH_SG("zh-SG"), // lf
	ZH_TW("zh-TW"), // lf
	ZU("zu"), // lf
	ZU_ZA("zu-ZA");

	private final String culture;

	/**
	 * Constructor
	 */
	private KendoCulture(String culture)
	{
		this.culture = culture;
	}

	@Override
	public String toString()
	{
		return this.culture;
	}

	/**
	 * Indicates whether the specified {@link Locale} is currently supported
	 * 
	 * @param locale the {@code Locale}
	 * @return {@code true} or {@code false}
	 */
	public static boolean exists(Locale locale)
	{
		return KendoCulture.exists(locale.toLanguageTag());
	}

	/**
	 * Indicates whether the specified culture is currently supported
	 * 
	 * @param culture the culture
	 * @return {@code true} or {@code false}
	 */
	public static boolean exists(String culture)
	{
		if (culture != null)
		{
			for (KendoCulture c : KendoCulture.values())
			{
				if (culture.equalsIgnoreCase(c.toString()))
				{
					return true;
				}
			}
		}

		return false;
	}

	/**
	 * Gets the first supported culture in the specified array of cultures
	 * 
	 * @param cultures the array of cultures
	 * @return the first supported culture, or {@code null}
	 */
	public static String get(String... cultures)
	{
		for (String culture : cultures)
		{
			if (KendoCulture.exists(culture))
			{
				return culture;
			}
		}

		return null;
	}
}
